==> gnuastro-0.2.tar.gz: gnuastro-0.2/lib/gnuastro/gnuastro.h <==
/*********************************************************************
Functions dealing with general aspects of all Gnuastro.

Original author:
     Mohammad Akhlaghi <akhlaghi@gnu.org>
Contributing author(s):
Copyright (C) 2016, Free Software Foundation, Inc.

Gnuastro is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Gnuastro is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
**********************************************************************/
#ifndef __GAL_GNUASTRO_H__
#define __GAL_GNUASTRO_H__

/* Include other headers if necessary here. Note that other header files
   must be included before the C++ preparations below */



/* Macros. In gnuastro.h.in, the values in `@' --- `@'', will be replaced
   with installation specific values. */
#define GAL_GNUASTRO_VERSION "0.2"
#define GAL_GNUASTRO_PTHREAD_BARRIER 1



/* C++ Preparations */
#undef __BEGIN_C_DECLS
#undef __END_C_DECLS
#ifdef __cplusplus
# define __BEGIN_C_DECLS extern "C" {
# define __END_C_DECLS }
#else
# define __BEGIN_C_DECLS                /* empty */
# define __END_C_DECLS                  /* empty */
#endif
/* End of C++ preparations */



/* Actual header contants (the above were for the Pre-processor). */
__BEGIN_C_DECLS  /* From C++ preparations */






__END_C_DECLS    /* From C++ preparations */

#endif           /* __GAL_GNUASTRO_H__ */

==> gnuastro_0.2.33.orig.tar.gz: gnuastro-0.2.33-8a3b/lib/gnuastro/gnuastro.h <==
/*********************************************************************
Functions dealing with general aspects of all Gnuastro.

Original author:
     Mohammad Akhlaghi <akhlaghi@gnu.org>
Contributing author(s):
Copyright (C) 2016, Free Software Foundation, Inc.

Gnuastro is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Gnuastro is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
**********************************************************************/
#ifndef __GAL_GNUASTRO_H__
#define __GAL_GNUASTRO_H__

/* Include other headers if necessary here. Note that other header files
   must be included before the C++ preparations below */



/* Macros. In gnuastro.h.in, the values in `@' --- `@'', will be replaced
   with installation specific values. */
#define GAL_GNUASTRO_VERSION "0.2.33-8a3b"
#define GAL_GNUASTRO_HAVE_LIBGIT2 1
#define GAL_GNUASTRO_HAVE_PTHREAD_BARRIER 1



/* C++ Preparations */
#undef __BEGIN_C_DECLS
#undef __END_C_DECLS
#ifdef __cplusplus
# define __BEGIN_C_DECLS extern "C" {
# define __END_C_DECLS }
#else
# define __BEGIN_C_DECLS                /* empty */
# define __END_C_DECLS                  /* empty */
#endif
/* End of C++ preparations */



/* Actual header contants (the above were for the Pre-processor). */
__BEGIN_C_DECLS  /* From C++ preparations */






__END_C_DECLS    /* From C++ preparations */

#endif           /* __GAL_GNUASTRO_H__ */
